@@ -31,6 +31,7 @@ import cv2
 import numpy as np
 
 from imgaug import augmenters as iaa
+from imgaug.augmentables.bbs import BoundingBoxesOnImage, BoundingBox as BoundingBoxAug
 from keras.utils.data_utils import Sequence
 
 from .processing import BoundingBox
@@ -114,6 +115,19 @@ class BatchGenerator(Sequence):
         if shuffle:
             np.random.shuffle(self._data)
 
+    def list2bbox(self, boxes, image_shape):
+        """ Transforms bounding boxes from numpy array to BoundingBox format from imgaug library.
+        """
+        formattedbox = [BoundingBoxAug(x1=box["x1"], y1=box["y1"], x2=box["x2"], y2=box["y2"],
+                        label=box['label']) for box in boxes]
+        return BoundingBoxesOnImage(formattedbox, shape=image_shape)
+
+    def bbox2list(self, boxes):
+        """ Extracts bounding boxes from imgaug object to numpy array.
+        """
+        return [{"label": box.label, "x1": box.x1, "y1": box.y1, "x2": box.x2, "y2": box.y2}
+                for box in boxes]
+
     def __len__(self):
         return int(np.ceil(float(self._data_length) / self._batch_size))
 
@@ -246,7 +260,11 @@ class BatchGenerator(Sequence):
             if flip > 0.5:
                 image = cv2.flip(image, 1)
 
-            image = self._aug_pipe.augment_image(image)
+            # augment both image and boxes
+            bbs = self.list2bbox(all_objs, image.shape)
+            image, bbs = self._aug_pipe(image=image, bounding_boxes=bbs)
+            bbs.remove_out_of_image().clip_out_of_image()
+            all_objs = self.bbox2list(bbs)
 
         # resize the image to standard size
         image = cv2.resize(image, (self._input_shape[0], self._input_shape[1]))
