@@ -142,7 +142,8 @@ class YoloLoss():
                                    use_iou=self.readjust_obj_score)
         b_o_pred = y_pred[..., 4]
 
-        num_true_labels = self.grid_size[0] * self.grid_size[1] * self.nb_anchors
+        num_true_labels = self.grid_size[0] * \
+            self.grid_size[1] * self.nb_anchors
         y_true_p = K.reshape(y_true[..., :4],
                              shape=(self.batch_size, 1, 1, 1, num_true_labels,
                                     4))
