@@ -30,7 +30,7 @@ from cnn2snn import load_quantized_model, convert
 
 from ..cyclic_lr import CyclicLR
 from ..training import (get_training_parser, compile_model, evaluate_model,
-                        evaluate_akida_model)
+                        evaluate_akida_model, print_history_stats)
 
 
 def get_data(dataset, batch_size):
@@ -109,7 +109,7 @@ def train_model(model, train_ds, test_ds, batch_size, max_learning_rate, epochs,
                         epochs=epochs,
                         callbacks=[lr_scheduler],
                         validation_data=test_ds)
-    print(history.history)
+    print_history_stats(history)
 
 
 def main():
