@@ -28,10 +28,9 @@ import tensorflow as tf
 import tensorflow_datasets as tfds
 
 import keras
-from keras.callbacks import TensorBoard, ModelCheckpoint, LearningRateScheduler, Callback
+from keras.callbacks import TensorBoard, ModelCheckpoint, LearningRateScheduler
 from keras import Sequential
-from keras.optimizer_v2.gradient_descent import SGD
-from keras.optimizer_v2.adam import Adam
+from keras.optimizers import SGD, Adam
 from tensorflow_addons.optimizers import LAMB
 from keras.layers import Input, Activation
 from keras.models import clone_model
@@ -39,35 +38,14 @@ from keras.models import clone_model
 import akida
 from cnn2snn import load_quantized_model, convert
 from quantizeml.layers import AddPositionEmbs, ClassToken
-from quantizeml.models import load_model, set_calibrate
+from quantizeml.models import load_model
 
 from .preprocessing import preprocess_image, DATA_AUGMENTATION
-from ..training import get_training_parser, freeze_model_before, print_history_stats
+from ..training import (get_training_parser, freeze_model_before, print_history_stats,
+                        EarlyStoppingCalibration)
 from ..transformers.model_vit import apply_embedding_weights
 
 
-class EarlyStoppingCalibration(Callback):
-    """A callback that limits the number of epochs to calibrate the model,
-        increasing the speed of the training.
-
-    Args:
-        trigger_epoch (int, optional): epoch at which to end the calibration.
-            Defaults to calibrate until the end of the training.
-
-    Notes:
-        If the :attr:`trigger_epoch` is set to 0, the model will never be calibrated
-    """
-
-    def __init__(self, trigger_epoch=-1):
-        self.trigger_epoch = trigger_epoch
-
-    def on_epoch_begin(self, epoch, logs=None):
-        calibrate = epoch < self.trigger_epoch or self.trigger_epoch < 0
-        set_calibrate(self.model, calibrate)
-        if logs is not None:
-            logs["calibrating"] = calibrate
-
-
 def get_imagenet_dataset(data_path, training, image_size, batch_size, data_aug=True, one_hot=False):
     """ Loads ImageNet 2012 dataset and builds a tf.dataset out of it.
 
@@ -554,6 +532,9 @@ def main():
         val_ds, val_steps = get_imagenet_dataset(args.data_dir, False, im_size,
                                                  args.batch_size, data_aug=False, one_hot=one_hot)
 
+    # Disable QuantizeML assertions
+    os.environ["ASSERT_ENABLED"] = "0"
+
     # Train model
     if args.action in ['train', 'tune']:
         # Load training data
