@@ -27,7 +27,7 @@ from keras.utils.data_utils import get_file
 from cnn2snn import load_quantized_model, quantize_layer, convert
 
 from ..cyclic_lr import CyclicLR
-from ..training import get_training_parser, compile_model, evaluate_model
+from ..training import get_training_parser, compile_model, evaluate_model, print_history_stats
 
 
 def get_data():
@@ -86,7 +86,7 @@ def train_model(model, x_train, y_train, x_val, y_val, batch_size, epochs):
                         verbose=1,
                         validation_data=(x_val, to_categorical(y_val)),
                         callbacks=callbacks)
-    print(history.history)
+    print_history_stats(history)
 
 
 def main():
