@@ -20,12 +20,13 @@ Layers blocks definitions.
 from functools import partial
 
 from keras.layers import (BatchNormalization, ReLU, Conv2D, SeparableConv2D, Dense, MaxPool2D,
-                          AvgPool2D, GlobalAvgPool2D, LayerNormalization, Dropout, Add)
+                          AvgPool2D, GlobalAvgPool2D, LayerNormalization, Dropout, Add,
+                          Conv2DTranspose)
 from keras.activations import swish
 from keras.initializers import TruncatedNormal
 from tensorflow_addons.layers import GELU, GroupNormalization
 
-from quantizeml.layers import Attention, LayerMadNormalization
+from quantizeml.layers import Attention, LayerMadNormalization, SeparableConv2DTranspose
 
 
 def _add_pooling_layer(x, pooling_type, pool_size, padding, layer_base_name):
@@ -58,8 +59,7 @@ def _add_pooling_layer(x, pooling_type, pool_size, padding, layer_base_name):
                          name=layer_base_name + '_avgpool')(x)
     if pooling_type == 'global_avg':
         return GlobalAvgPool2D(name=layer_base_name + '_global_avg')(x)
-    raise ValueError("'pooling_type' argument must be 'max', "
-                     "'avg' or 'global_avg'.")
+    raise ValueError("'pooling_type' argument must be 'max', 'avg' or 'global_avg'.")
 
 
 def conv_block(inputs,
@@ -97,12 +97,9 @@ def conv_block(inputs,
         tf.Tensor: output tensor of conv2D block.
     """
     if 'activation' in kwargs and kwargs['activation']:
-        raise ValueError(
-            "Keyword argument 'activation' in conv_block must be None.")
-    if 'dilation_rate' in kwargs:
-        if kwargs['dilation_rate'] != 1 and kwargs['dilation_rate'] != (1, 1):
-            raise ValueError("Keyword argument 'dilation_rate' is not "
-                             "supported in conv_block.")
+        raise ValueError("Keyword argument 'activation' in conv_block must be None.")
+    if 'dilation_rate' in kwargs and kwargs['dilation_rate'] not in [1, [1, 1], (1, 1)]:
+        raise ValueError("Keyword argument 'dilation_rate' is not supported in conv_block.")
 
     conv_layer = Conv2D(filters, kernel_size, **kwargs)
     x = conv_layer(inputs)
@@ -155,16 +152,13 @@ def separable_conv_block(inputs,
         tf.Tensor: output tensor of separable conv block.
     """
     if 'activation' in kwargs and kwargs['activation']:
-        raise ValueError("Keyword argument 'activation' in separable_conv_block"
-                         " must be None.")
-    if 'dilation_rate' in kwargs:
-        if kwargs['dilation_rate'] != 1 and kwargs['dilation_rate'] != (1, 1):
-            raise ValueError("Keyword argument 'dilation_rate' is not "
-                             "supported in separable_conv_block.")
-    if 'depth_multiplier' in kwargs:
-        if kwargs['depth_multiplier'] != 1:
-            raise ValueError("Keyword argument 'depth_multiplier' is not "
-                             "supported in separable_conv_block.")
+        raise ValueError("Keyword argument 'activation' in separable_conv_block must be None.")
+    if 'dilation_rate' in kwargs and kwargs['dilation_rate'] not in [1, [1, 1], (1, 1)]:
+        raise ValueError("Keyword argument 'dilation_rate' is not supported in "
+                         "separable_conv_block.")
+    if 'depth_multiplier' in kwargs and kwargs['depth_multiplier'] != 1:
+        raise ValueError("Keyword argument 'depth_multiplier' is not "
+                         "supported in separable_conv_block.")
 
     sep_conv_layer = SeparableConv2D(filters, kernel_size, **kwargs)
     x = sep_conv_layer(inputs)
@@ -202,8 +196,7 @@ def dense_block(inputs,
         tf.Tensor: output tensor of the dense block.
     """
     if 'activation' in kwargs and kwargs['activation']:
-        raise ValueError("Keyword argument 'activation' in dense_block"
-                         " must be None.")
+        raise ValueError("Keyword argument 'activation' in dense_block must be None.")
 
     dense_layer = Dense(units, **kwargs)
     x = dense_layer(inputs)
@@ -384,3 +377,90 @@ def transformer_block(inputs, num_heads, hidden_size, mlp_dim, dropout, name,
     y = mlp_block(y, mlp_dim, dropout, f"{name}/MlpBlock", mlp_act)
     outputs = Add(name=f"{name}/add_2")([x_norm2, y])
     return outputs, (weights, x_norm2)
+
+
+def conv_transpose_block(inputs,
+                         filters,
+                         kernel_size,
+                         add_batchnorm=False,
+                         add_activation=True,
+                         **kwargs):
+    """Adds a transposed convolutional layer with optional layers in the following order:
+    batch normalization, activation.
+
+    Args:
+        inputs (tf.Tensor): input tensor of shape `(rows, cols, channels)`
+        filters (int): the dimensionality of the output space (i.e. the number of output filters in
+            the convolution).
+        kernel_size (int or tuple of 2 integers): specifying the height and width of the 2D
+            convolution kernel. Can be a single integer to specify the same value for all spatial
+            dimensions.
+        add_batchnorm (bool, optional): add a BatchNormalization layer. Defaults to False.
+        add_activation (bool, optional): add a ReLU8 layer. Defaults to True.
+        **kwargs: arguments passed to the keras.Conv2DTranspose layer, such as strides, padding,
+            use_bias, weight_regularizer, etc.
+
+    Returns:
+        tf.Tensor: output tensor of transposed convolution block.
+    """
+    if 'activation' in kwargs and kwargs['activation']:
+        raise ValueError("Keyword argument 'activation' in conv_transpose_block must be None.")
+    if 'dilation_rate' in kwargs and kwargs['dilation_rate'] not in [1, [1, 1], (1, 1)]:
+        raise ValueError("Keyword argument 'dilation_rate' is not supported in "
+                         "conv_transpose_block.")
+
+    conv_trans_layer = Conv2DTranspose(filters, kernel_size, **kwargs)
+    x = conv_trans_layer(inputs)
+
+    if add_batchnorm:
+        x = BatchNormalization(name=conv_trans_layer.name + '_BN')(x)
+
+    if add_activation:
+        x = ReLU(8.0, name=conv_trans_layer.name + '_relu')(x)
+
+    return x
+
+
+def sepconv_transpose_block(inputs,
+                            filters,
+                            kernel_size,
+                            add_batchnorm=False,
+                            add_activation=True,
+                            **kwargs):
+    """Adds a transposed separable convolutional layer with optional layers in the following order:
+    batch normalization, activation.
+
+    Args:
+        inputs (tf.Tensor): input tensor of shape `(rows, cols, channels)`
+        filters (int): the dimensionality of the output space (i.e. the number of output filters in
+            the pointwise convolution).
+        kernel_size (int or tuple of 2 integers): specifying the height and width of the 2D
+            convolution kernel. Can be a single integer to specify the same value for all spatial
+            dimensions.
+        add_batchnorm (bool, optional): add a BatchNormalization layer. Defaults to False.
+        add_activation (bool, optional): add a ReLU8 layer. Defaults to True.
+        **kwargs: arguments passed to the SeparableConv2DTranspose layer, such as strides, padding,
+            use_bias, weight_regularizer, etc.
+
+    Returns:
+        tf.Tensor: output tensor of transposed separable convolution block.
+    """
+    if 'activation' in kwargs and kwargs['activation']:
+        raise ValueError("Keyword argument 'activation' in separable_conv_block must be None.")
+    if 'dilation_rate' in kwargs and kwargs['dilation_rate'] not in [1, [1, 1], (1, 1)]:
+        raise ValueError("Keyword argument 'dilation_rate' is not supported in "
+                         "separable_conv_block.")
+    if 'depth_multiplier' in kwargs and kwargs['depth_multiplier'] != 1:
+        raise ValueError("Keyword argument 'depth_multiplier' is not "
+                         "supported in separable_conv_block.")
+
+    sepconv_trans_layer = SeparableConv2DTranspose(filters, kernel_size, **kwargs)
+    x = sepconv_trans_layer(inputs)
+
+    if add_batchnorm:
+        x = BatchNormalization(name=sepconv_trans_layer.name + '_BN')(x)
+
+    if add_activation:
+        x = ReLU(8.0, name=sepconv_trans_layer.name + '_relu')(x)
+
+    return x
