@@ -19,7 +19,7 @@ Training script for MNIST models.
 """
 
 from keras.datasets import mnist
-from keras.optimizer_v2.adam import Adam
+from keras.optimizers import Adam
 from keras.metrics import SparseCategoricalAccuracy
 from keras.losses import SparseCategoricalCrossentropy
 
