@@ -28,7 +28,7 @@ from cnn2snn import load_quantized_model, convert
 
 from .preprocessing import get_modelnet, get_modelnet_from_file
 
-from ..training import get_training_parser, compile_model
+from ..training import get_training_parser, compile_model, print_history_stats
 
 
 def get_data(batch_size, selected_points, knn_points):
@@ -82,7 +82,7 @@ def train_model(model, train_dataset, test_dataset, epochs):
                         validation_data=test_dataset,
                         epochs=epochs,
                         callbacks=callbacks)
-    print(history.history)
+    print_history_stats(history)
 
 
 def evaluate_model(model, test_dataset):
